@@ -4,7 +4,7 @@ use base 'Perinci::To::DocBase::I18N';
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -20,7 +20,7 @@ Perinci::To::DocBase::I18N::id - Indonesian translation for Perinci::To::DocBase
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
@@ -199,3 +199,12 @@ msgstr "Fungsi ini mendukung operasi undo (pembatalan). Silakan baca 'The undo p
 msgid  "This function is declared as %1 (%2). Please read the '%1' feature in Rinci::function specification."
 msgid  "Fungsi ini dideklarasikan %1 (%2). Silakan baca fitur '%1' di spesifikasi Rinci::function."
 
+# test multiline
+
+msgid  ""
+"Line 1"
+"Line 2"
+msgstr ""
+"Baris 1"
+"Baris 2"
+
