@@ -4,7 +4,7 @@ use parent qw(Perinci::To::Text::I18N Perinci::To::DocBase::I18N::id);
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -12,7 +12,6 @@ our $VERSION = '0.06'; # VERSION
 # ABSTRACT: Indonesian translation for Perinci::To::Text
 
 
-
 =pod
 
 =head1 NAME
@@ -21,7 +20,7 @@ Perinci::To::Text::I18N::id - Indonesian translation for Perinci::To::Text
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
@@ -37,4 +36,6 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 
-__DATA__
\ No newline at end of file
+__DATA__
+msgid  ""
+msgstr ""
